@@ -133,7 +133,7 @@ impl Default for MapMessage{
 
 /// Message enum wich represents the different message types
 #[allow(dead_code)]
-#[derive(Debug, Clone)]
+#[derive(Debug, Clone, Serialize, Deserialize)]
 pub enum Message {
   /// represents a Text Message
   TextMessage(TextMessage),
@@ -1088,9 +1088,14 @@ fn build_message_from_pointer(msg_pointer: usize) -> Message {
                   }
                 },
                 tibems_status::TIBEMS_CONVERSION_FAILED => {
+                  //it must be a map msg inside
                   let mut msg2: usize = 0;
                   let status = tibco_ems_sys::tibemsMapMsg_GetMapMsg(msg_pointer, buf_ref, &mut msg2);
                   match status {
+                    tibems_status::TIBEMS_CONVERSION_FAILED => {
+                      //it must be something binary, ingore it for now
+                      trace!("tibemsMapMsg_GetMapMsg: ignoring unkown content");
+                    },
                     tibems_status::TIBEMS_OK => trace!("tibemsMapMsg_GetMapMsg: {:?}",status),
                     _ => error!("tibemsMapMsg_GetMapMsg: {:?}",status),
                   }
